CKEDITOR.plugins.setLang('youtube', 'hu', {
	button : 'Youtube videó beillesztése',
	title : 'Youtube videó beillesztése',
	txtEmbed : 'Illessze be a beágyazott kódot',
	txtUrl : 'Illessze be a Youtube videó URL-jét',
	txtWidth : 'Szélesség',
	txtHeight : 'Magasság',
	txtStartAt : 'Kezdő időpont (ss vagy mm:ss vagy hh:mm:ss)',
	chkRelated : 'Ajánlott videók megjelenítése, amikor a videó befejeződik',
	chkPrivacy : 'Fokozott adatvédelmi mód engedélyezése',
	chkOlderCode : 'Régi beágyazott kód használata',
	chkAutoplay : 'Automatikus lejátszás',
	chkControls : 'Lejátszásvezérlők mutatása',
	noCode : 'A beágyazott kód, vagy az URL megadása kötelező',
	invalidEmbed : 'A beágyazott kód érvénytelen',
	invalidUrl : 'A megadott URL érvénytelen',
	or : 'vagy',
	noWidth : 'A szélesség megadása kötelező',
	invalidWidth : 'Érvényes szélességet adjon meg',
	noHeight : 'A magasság megadása kötelező',
	invalidHeight : 'Érvényes magasságot adjon meg',
	invalidTime : 'Érvényes kezdő időpontot adjon meg',
	txtResponsive : 'Reszponzív videó',
	txtNoEmbed : 'Csak kép és hivatkozás jelenjen meg'
});
